# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr





@to_json_decorator
@attr.s
class ImageBasicRecognizeReqBody(object):
    image = attr.ib(type=str, default=None, metadata={'json': 'image'})


@attr.s
class ImageBasicRecognizeResult(object):
    text_list = attr.ib(type=List[str], default=None, metadata={'json': 'text_list'})