# -*- coding: UTF-8 -*-
# Code generated by lark suite oapi sdk gen

from typing import List, Dict, Any
from ....utils.dt import to_json_decorator
import attr




@to_json_decorator
@attr.s
class Avatar(object):
    avatar_origin = attr.ib(type=str, default=None, metadata={'json': 'avatar_origin'})
    avatar_72 = attr.ib(type=str, default=None, metadata={'json': 'avatar_72'})
    avatar_240 = attr.ib(type=str, default=None, metadata={'json': 'avatar_240'})
    avatar_640 = attr.ib(type=str, default=None, metadata={'json': 'avatar_640'})


@to_json_decorator
@attr.s
class Tenant(object):
    name = attr.ib(type=str, default=None, metadata={'json': 'name'})
    display_id = attr.ib(type=str, default=None, metadata={'json': 'display_id'})
    tenant_tag = attr.ib(type=int, default=None, metadata={'json': 'tenant_tag'})
    tenant_key = attr.ib(type=str, default=None, metadata={'json': 'tenant_key'})
    avatar = attr.ib(type=Avatar, default=None, metadata={'json': 'avatar'})




@attr.s
class TenantQueryResult(object):
    tenant = attr.ib(type=Tenant, default=None, metadata={'json': 'tenant'})